# **Coded**

## Coded is a programming language and Python extension designed to make programming just a little bit easier.

With Coded, you can easily build projects - no matter how complex.  
Our libraries allow you to create whatever you can imagine, with just a few lines of code.

## Documentation

[View the full documentation](https://github.com/opendylan/coded.py)

### Current features:

* write
* writeline
* prompt
* clear
* rand
* readf
* writef
* rm
* rmdir
* syscmd
* envs
* pypath

And MANY more!

## Changelog

1.1:

* Created basic project structure
* Created Coded
* Added `write`

1.2:

* Added `writeline`

1.3:

* Added `prompt`
* Reconfigured program structure
* Removed submodules (e.g. `console.write` is now just `write`)
* Added changelog
* Added project description
* Added documentation link
* Fixed `writeline` tuple bug

1.4:

* Use `os` module
* Added `clear`
* Added [current features](#current-features) view.

1.5:

* Added function documentation inline
* Handles exceptions in `prompt`

All newer minor versions:

* Bug fixes
* New features
